import * as React from "react";
import Button from "@mui/material/Button";
import Dialog from "@mui/material/Dialog";
import AppBar from "@mui/material/AppBar";
import Toolbar from "@mui/material/Toolbar";
import IconButton from "@mui/material/IconButton";
import Typography from "@mui/material/Typography";
import CloseIcon from "@mui/icons-material/Close";
import Slide from "@mui/material/Slide";
import { Box, TextField } from "@mui/material";
import { usePage, useForm } from "@inertiajs/react";
import { useState } from "react";
import { useRef } from "react";
import { MdSend, MdImage, MdVideocam } from "react-icons/md";
import ReactQuill from "react-quill";
import "react-quill/dist/quill.snow.css"; 

const Transition = React.forwardRef(function Transition(props, ref) {
    return <Slide direction="up" ref={ref} {...props} />;
});


export default function CreatePost({ firstName, firstCharacter, onPostCreate }) {
    const { auth, course, flash } = usePage().props;
    const [open, setOpen] = React.useState(false);
    const [content, setContent] = React.useState("");
    const [image, setImage] = React.useState(null);
    const [imagePreview, setImagePreview] = React.useState("");

    const { data, setData, post, processing, errors } = useForm({
        // Initial form data
        content: '',
        image: '',
        // videoUrl: null,
    });

    const handleClickOpen = () => {
        setOpen(true);
    };

    const handleClose = () => {
        setOpen(false);
    };

    const handleSubmit = () => {
 

        
        post(route('post.store'), {
            onSuccess: (response) => {
                // Close the dialog on successful submission

                console.log("response is : ",response.props.posts)
                setOpen(false);

                onPostCreate(response.props.posts); // Pass the new post to refresh

    
                // Optionally, you can reset the form here
                setData({
                    content: '',
                    image: '',
                    // videoUrl: null,
                });

               
            },
        });

   
    }; 

    const [imageUrl, setImageUrl] = useState("");
    // const [videoUrl, setVideoUrl] = useState("");
    const [messageOpen, setMessageOpen] = useState(false);
    // const [message, setMessage] = useState("");
    const fileInputRef = useRef(null);
    const fileVideoRef = useRef(null);

    const handleMessageChange = () => {
        setMessageOpen(!messageOpen);
    };

    const handleFileChange = (event) => {
        const file = event.target.files[0];
        if (file) {
            const url = URL.createObjectURL(file);
            setImageUrl(url);
            setData("image", file);
        }
    };

    const handleVideoChange = (event) => {
        const file = event.target.files[0];
        if (file) {
            const url = URL.createObjectURL(file);
            // setVideoUrl(url);
            setData("videoUrl", url);


            // Add file upload logic here
        }
    };

    const handleVideoClick = () => {
        fileVideoRef.current.click(); // Trigger the file input click event
    };

    const handleImageClick = () => {
        fileInputRef.current.click(); // Trigger the file input click event
    };

    return (
        <React.Fragment>
            <Button className="bg-transparent w-full" onClick={handleClickOpen}>
                <div className="d-flex p-2 gap-4 w-full">
                    <span className="gradient-color px-2 py-1 h-9 w-9 text-white text-center border border-secondry rounded-circle">
                        { firstCharacter }
                    </span>
                    <div className="w-full">
                        <textarea
                            className="w-full rounded-xl border-inherit"
                            placeholder={"Hey "+ firstName + ", what’s your view on markets today?"}
                        />
                    </div>
                </div>
            </Button>
            <Dialog
                fullScreen
                open={open}
                onClose={handleClose}
                TransitionComponent={Transition}
            >
                <AppBar
                    sx={{
                        position: "relative",
                        backgroundImage:
                            "linear-gradient(to right top, #ec4899, #dc32a4, #c721b1, #a91abf, #7e22ce)",
                    }}
                >
                    <Toolbar>
                        <IconButton
                            edge="start"
                            color="inherit"
                            onClick={handleClose}
                            aria-label="close"
                        >
                            <CloseIcon />
                        </IconButton>
                        <Typography
                            sx={{ ml: 2, flex: 1 }}
                            variant="h6"
                            component="div"
                        >
                            Create Post
                        </Typography>
                        <Button
                            autoFocus
                            color="inherit"
                            onClick={handleSubmit}
                        >
                            Post Now
                        </Button>
                    </Toolbar>
                </AppBar>

                <Box
                    component="form"
                    sx={{
                        display: "flex",
                        flexDirection: "column",
                        alignItems: "center",
                        m: 2,
                        gap: 2,
                    }}
                    noValidate
                    autoComplete="off"
                >
                    <div className="w-full">
                        <Box
                            sx={{
                                padding: "10px",
                                borderTop: "1px solid #ddd",
                                display: "flex",
                                alignItems: "center",
                                backgroundColor: "",
                            }}
                        >
                            {/* <IconButton color="primary"></IconButton> */}
                            <div className="relative w-full">
                            <ReactQuill
                                      value={data?.content || ''}  // Ensure content is passed correctly to React Quill
                                      onChange={(value) => setData({ ...data, content: value })} 
                                    theme="snow"
                                    style={{ height: "200px" }} 
                                    modules={{
                                    toolbar: [
                                        [{ header: "1" }, { header: "2" }, { font: [] }],
                                        [{ list: "ordered" }, { list: "bullet" }],
                                        ["bold", "italic", "underline"],
                                        [{ align: [] }],
                                        ["link"],
                                        ["image"],
                                    ],
                                    }}
                                />
                                {/* <textarea
                                    className="resize-none w-full h-24 rounded-xl pr-4"
                                    value={data?.text}
                                    onChange={(e) => setData("content", e.target.value )}
                                    onKeyDown={(e) =>
                                        e.key === "Enter" && handleSend()
                                    }
                                    placeholder="Type a message"
                                    variant="outlined"
                                    fullwidth
                                    size="small"
                                    sx={{
                                        marginLeft: "10px",
                                        marginRight: "10px",
                                    }}
                                /> */}
                                <div className="flex flex-col absolute right-0 inset-y-3 top-0">
                                    <IconButton
                                        color="primary"
                                        onClick={handleImageClick}
                                    >
                                        <input
                                            type="file"
                                            hidden
                                            ref={fileInputRef}
                                            onChange={(e) =>
                                                handleFileChange(e)
                                            }
                                        />
                                        <MdImage style={{ fontSize: "25px" }} />Add Image
                                    </IconButton>
                                    {/* <IconButton
                                        color="primary"
                                        onClick={handleVideoClick}
                                    >
                                        <input
                                            type="file"
                                            hidden
                                            ref={fileVideoRef}
                                            onChange={(e) =>
                                                handleVideoChange(e)
                                            }
                                        />
                                        <MdVideocam />
                                    </IconButton> */}
                                </div>
                            </div>
                        </Box>
                        <div>
                            <div className="d-flex">
                                <div
                                    className="d-flex"
                                    style={{ width: "50%" }}
                                >
                                    {imageUrl !== "" && (
                                        <div
                                            className="d-flex flex-column justify-content-center align-items-center"
                                            style={{ width: "100%" }}
                                        >
                                            <img
                                                src={imageUrl}
                                                alt="Image"
                                                style={{
                                                    height: "400px",
                                                    width: "100%",
                                                }}
                                            />
                                        </div>
                                    )}
                                </div>
                                {/* <div
                                    className="d-flex"
                                    style={{ width: "50%" }}
                                >
                                    {data.videoUrl !== null && (
                                        <div
                                            className="d-flex flex-column justify-content-center align-items-center"
                                            style={{ width: "100%" }}
                                        >
                                            <video
                                                src={data.videoUrl}
                                                alt="Video"
                                                controls
                                                style={{ width: "100%" }}
                                            />
                                        </div>
                                    )}
                                </div> */}
                            </div>
                        </div>
                    </div>
                </Box>
            </Dialog>
        </React.Fragment>
    );
}
